-- The following functions are the minimum required for case-insensitive text (citext)

CREATE FUNCTION pg_catalog.citextin(cstring) RETURNS pg_catalog.citext AS 'textin'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citextin(cstring) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citextin(cstring) IS 'Input for case insensitive text';

CREATE FUNCTION pg_catalog.citextout(pg_catalog.citext) RETURNS cstring AS 'textout'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citextout(pg_catalog.citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citextout(pg_catalog.citext) IS 'Output for case insensitive text';

CREATE TYPE pg_catalog.citext(INPUT = citextin, OUTPUT = citextout, INTERNALLENGTH = -1, DELIMITER = ",", ALIGNMENT = int4, STORAGE = MAIN);
COMMENT ON TYPE citext IS 'variable-length case-insensitve string, no limit specified';

CREATE FUNCTION pg_catalog.citext_eq(citext, citext) RETURNS bool AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext_eq(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext_eq(citext, citext) IS '= operator for citext';

CREATE FUNCTION pg_catalog.citext_ne(citext, citext) RETURNS bool AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext_ne(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext_ne(citext, citext) IS '<> operator for citext';

CREATE FUNCTION pg_catalog.citext_lt(citext, citext) RETURNS bool AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext_lt(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext_lt(citext, citext) IS '< operator for citext';

CREATE FUNCTION pg_catalog.citext_le(citext, citext) RETURNS bool AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext_le(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext_le(citext, citext) IS '<= operator for citext';

CREATE FUNCTION pg_catalog.citext_gt(citext, citext) RETURNS bool AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext_gt(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext_gt(citext, citext) IS '> operator for citext';

CREATE FUNCTION pg_catalog.citext_ge(citext, citext) RETURNS bool AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext_ge(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext_ge(citext, citext) IS '>= operator for citext';

CREATE FUNCTION pg_catalog.citextcmp(citext, citext) RETURNS int4 AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citextcmp(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citextcmp(citext, citext) IS 'comparison function for btree indexing of citext';

CREATE FUNCTION pg_catalog.citext_smaller(citext, citext) RETURNS citext AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext_smaller(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext_smaller(citext, citext) IS 'smaller of two';

CREATE FUNCTION pg_catalog.citext_larger(citext, citext) RETURNS citext AS 'citext.so'  LANGUAGE 'C' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext_larger(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext_larger(citext, citext) IS 'smaller of two';

CREATE FUNCTION pg_catalog.textcat(citext, citext) RETURNS citext AS 'textcat'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.textcat(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.textcat(citext, citext) IS 'concatenate';

CREATE FUNCTION pg_catalog.textlen(citext) RETURNS int4 AS 'textlen'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.textlen(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.textlen(citext) IS 'length';
CREATE FUNCTION pg_catalog.length(citext) RETURNS int4 AS 'textlen'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.length(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.length(citext) IS 'length';

CREATE FUNCTION pg_catalog.texticlike(citext, citext) RETURNS bool AS 'texticlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticlike(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticlike(citext, citext) IS 'matches LIKE expression, case-insensitive';

CREATE FUNCTION pg_catalog.texticnlike(citext, citext) RETURNS bool AS 'texticnlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticnlike(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticnlike(citext, citext) IS 'does not match LIKE expression, case-insensitive';

CREATE FUNCTION pg_catalog.texticregexeq(citext, citext) RETURNS bool AS 'texticregexeq'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticregexeq(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticregexeq(citext, citext) IS 'matches regex., case-insensitive';

CREATE FUNCTION pg_catalog.texticregexne(citext, citext) RETURNS bool AS 'texticregexne'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticregexne(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticregexne(citext, citext) IS 'does not match regex., case-insensitive';

-- Operators
CREATE OPERATOR pg_catalog.~ (PROCEDURE = texticregexeq, LEFTARG = citext, RIGHTARG = citext, NEGATOR = !~, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.~* (PROCEDURE = texticregexeq, LEFTARG = citext, RIGHTARG = citext, NEGATOR = !~*, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.!~ (PROCEDURE = texticregexne, LEFTARG = citext, RIGHTARG = citext, NEGATOR = ~, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.!~* (PROCEDURE = texticregexne, LEFTARG = citext, RIGHTARG = citext, NEGATOR = ~*, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.~~ (PROCEDURE = texticlike, LEFTARG = citext, RIGHTARG = citext, NEGATOR = !~~, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.~~* (PROCEDURE = texticlike, LEFTARG = citext, RIGHTARG = citext, NEGATOR = !~~*, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.!~~ (PROCEDURE = texticnlike, LEFTARG = citext, RIGHTARG = citext, NEGATOR = ~~, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);
CREATE OPERATOR pg_catalog.!~~* (PROCEDURE = texticnlike, LEFTARG = citext, RIGHTARG = citext, NEGATOR = ~~*, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);
CREATE OPERATOR pg_catalog.< (PROCEDURE = citext_lt, LEFTARG = citext, RIGHTARG = citext, COMMUTATOR = >, NEGATOR = >=, RESTRICT = scalarltsel, JOIN = scalarltjoinsel);
CREATE OPERATOR pg_catalog.<= (PROCEDURE = citext_le, LEFTARG = citext, RIGHTARG = citext, COMMUTATOR = >=, NEGATOR = >, RESTRICT = scalarltsel, JOIN = scalarltjoinsel);
CREATE OPERATOR pg_catalog.<> (PROCEDURE = citext_ne, LEFTARG = citext, RIGHTARG = citext, COMMUTATOR = <>, NEGATOR = =, RESTRICT = neqsel, JOIN = neqjoinsel);
CREATE OPERATOR pg_catalog.= (PROCEDURE = citext_eq, LEFTARG = citext, RIGHTARG = citext, COMMUTATOR = =, NEGATOR = <>, RESTRICT = eqsel, JOIN = eqjoinsel);
CREATE OPERATOR pg_catalog.> (PROCEDURE = citext_gt, LEFTARG = citext, RIGHTARG = citext, COMMUTATOR = <, NEGATOR = <=, RESTRICT = scalargtsel, JOIN = scalargtjoinsel);
CREATE OPERATOR pg_catalog.>= (PROCEDURE = citext_ge, LEFTARG = citext, RIGHTARG = citext, COMMUTATOR = <=, NEGATOR = <, RESTRICT = scalargtsel, JOIN = scalargtjoinsel);
CREATE OPERATOR pg_catalog.|| (PROCEDURE = textcat, LEFTARG = citext, RIGHTARG = citext);

CREATE OPERATOR CLASS citext_ops 
	DEFAULT FOR	TYPE 	citext USING btree AS 
	OPERATOR 	1	< , 
	OPERATOR 	2 	<=, 
	OPERATOR 	3 	=, 
	OPERATOR 	4 	>=, 
	OPERATOR 	5 	>, 
	FUNCTION 	1	citextcmp(citext, citext);

CREATE CAST (citext AS text) WITHOUT FUNCTION AS IMPLICIT;
CREATE CAST (text AS citext) WITHOUT FUNCTION AS IMPLICIT;
CREATE CAST (citext AS varchar) WITHOUT FUNCTION AS IMPLICIT;
CREATE CAST (varchar AS citext) WITHOUT FUNCTION AS IMPLICIT;
CREATE CAST (citext AS bpchar) WITHOUT FUNCTION AS IMPLICIT;
CREATE CAST (bpchar AS citext) WITHOUT FUNCTION AS IMPLICIT;

-- These functions all just overloaded versions of the internal functions for text
CREATE FUNCTION pg_catalog.lower(citext) RETURNS citext AS 'lower'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.lower(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.lower(citext) IS 'Convert case insensitive text to lowercase (why?)';

CREATE FUNCTION pg_catalog.upper(citext) RETURNS citext AS 'upper'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.upper(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.upper(citext) IS 'Convert case insensitive text to uppercase (why?)';

CREATE FUNCTION pg_catalog.btrim(citext, citext) RETURNS citext AS 'btrim'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.btrim(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.btrim(citext, citext) IS 'trim both ends of string';

CREATE FUNCTION pg_catalog.btrim(citext) RETURNS citext AS 'select btrim($1, '' ''::citext)'  LANGUAGE 'sql' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.btrim(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.btrim(citext) IS 'trim both ends of string';

CREATE FUNCTION pg_catalog.ltrim(citext, citext) RETURNS citext AS 'ltrim'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.ltrim(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.ltrim(citext, citext) IS 'left-pad string to length';

CREATE FUNCTION pg_catalog.ltrim(citext) RETURNS citext AS 'select ltrim($1, '' ''::citext)'  LANGUAGE 'sql' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.ltrim(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.ltrim(citext) IS 'remove initial characters from string';

CREATE FUNCTION pg_catalog.rtrim(citext, citext) RETURNS citext AS 'rtrim'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.rtrim(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.rtrim(citext, citext) IS 'right-pad string to length';

CREATE FUNCTION pg_catalog.rtrim(citext) RETURNS citext AS 'select rtrim($1, '' ''::citext)'  LANGUAGE 'sql' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.rtrim(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.rtrim(citext) IS 'remove trailing characters from string';

CREATE FUNCTION pg_catalog.lpad(citext, int4, citext) RETURNS citext AS 'lpad'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.lpad(citext, int4, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.lpad(citext, int4, citext) IS 'left-pad string to length';

CREATE FUNCTION pg_catalog.lpad(citext, int4) RETURNS citext AS 'select lpad($1, $2, '' '')'  LANGUAGE 'sql' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.lpad(citext, int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.lpad(citext, int4) IS 'left-pad string to length';

CREATE FUNCTION pg_catalog.rpad(citext, int4, citext) RETURNS citext AS 'rpad'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.rpad(citext, int4, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.rpad(citext, int4, citext) IS 'right-pad string to length';

CREATE FUNCTION pg_catalog.rpad(citext, int4) RETURNS citext AS 'select rpad($1, $2, '' ''::citext)'  LANGUAGE 'sql' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.rpad(citext, int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.rpad(citext, int4) IS 'right-pad string to length';

CREATE FUNCTION pg_catalog.repeat(citext, int4) RETURNS citext AS 'repeat'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.repeat(citext, int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.repeat(citext, int4) IS 'replicate string int4 times';

CREATE FUNCTION pg_catalog."substring"(citext, int4, int4) RETURNS citext AS 'text_substr'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog."substring"(citext, int4, int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog."substring"(citext, int4, int4) IS 'return portion of string';

CREATE FUNCTION pg_catalog."substring"(citext, int4) RETURNS citext AS 'text_substr_no_len'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog."substring"(citext, int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog."substring"(citext, int4) IS 'return portion of string';

CREATE FUNCTION pg_catalog.substr(citext, int4, int4) RETURNS citext AS 'text_substr'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.substr(citext, int4, int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.substr(citext, int4, int4) IS 'return portion of string';

CREATE FUNCTION pg_catalog.substr(citext, int4) RETURNS citext AS 'text_substr_no_len'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.substr(citext, int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.substr(citext, int4) IS 'return portion of string';

CREATE FUNCTION pg_catalog.to_timestamp(citext, citext) RETURNS timestamptz AS 'to_timestamp'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_timestamp(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_timestamp(citext, citext) IS 'convert citext to timestamp';

CREATE FUNCTION pg_catalog.to_number(citext, citext) RETURNS "numeric" AS 'numeric_to_number'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_number(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_number(citext, citext) IS 'convert citext to numeric';

CREATE FUNCTION pg_catalog.to_date(citext, citext) RETURNS "date" AS 'to_date'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_date(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_date(citext, citext) IS 'convert citext to date';

CREATE FUNCTION pg_catalog.to_char("interval", citext) RETURNS citext AS 'interval_to_char'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_char("interval", citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_char("interval", citext) IS 'format interval to citext';

CREATE FUNCTION pg_catalog.to_char(float8, citext) RETURNS citext AS 'float8_to_char'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_char(float8, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_char(float8, citext) IS 'format float8 to citext';

CREATE FUNCTION pg_catalog.to_char(float4, citext) RETURNS citext AS 'float4_to_char'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_char(float4, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_char(float4, citext) IS 'format float4 to citext';

CREATE FUNCTION pg_catalog.to_char(int8, citext) RETURNS citext AS 'int8_to_char'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_char(int8, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_char(int8, citext) IS 'format int8 to citext';

CREATE FUNCTION pg_catalog.to_char(int4, citext) RETURNS citext AS 'int4_to_char'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_char(int4, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_char(int4, citext) IS 'format int4 to citext';

CREATE FUNCTION pg_catalog.to_char(numeric, citext) RETURNS citext AS 'numeric_to_char'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_char(numeric, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_char("numeric", citext) IS 'format numeric to citext';

CREATE FUNCTION pg_catalog.to_char(timestamptz, citext) RETURNS citext AS 'timestamptz_to_char'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_char(timestamptz, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_char(timestamptz, citext) IS 'format timestamp with time zone to citext';

CREATE FUNCTION pg_catalog.to_char("timestamp", citext) RETURNS citext AS 'timestamp_to_char'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_char("timestamp", citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_char("timestamp", citext) IS 'format timestamp to citext';

CREATE FUNCTION pg_catalog.to_ascii(citext, name) RETURNS citext AS 'to_ascii_encname'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_ascii(citext, name) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_ascii(citext, name) IS 'encode citext from encoding to ASCII citext';

CREATE FUNCTION pg_catalog.to_ascii(citext, int4) RETURNS citext AS 'to_ascii_enc'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_ascii(citext, int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_ascii(citext, int4) IS 'encode citext from encoding to ASCII citext';

CREATE FUNCTION pg_catalog.to_ascii(citext) RETURNS citext AS 'to_ascii_default'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.to_ascii(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.to_ascii(citext) IS 'encode citext from DB encoding to ASCII citext';

CREATE FUNCTION pg_catalog.citext(oid) RETURNS citext AS 'oid_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(oid) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(oid) IS 'convert oid to citext';
CREATE FUNCTION pg_catalog.oid(citext) RETURNS oid AS 'text_oid'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.oid(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.oid(citext) IS 'convert citext to oid';
CREATE CAST (citext AS oid) WITH FUNCTION oid(citext);
CREATE CAST (oid AS citext) WITH FUNCTION citext(oid);

CREATE FUNCTION pg_catalog.citext(int2) RETURNS citext AS 'int2_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(int2) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(int2) IS 'convert int2 to citext';
CREATE FUNCTION pg_catalog.int2(citext) RETURNS int2 AS 'text_int2'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.int2(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.int2(citext) IS 'convert citext to int2';
CREATE CAST (citext AS int2) WITH FUNCTION int2(citext);
CREATE CAST (int2 AS citext) WITH FUNCTION citext(int2);

CREATE FUNCTION pg_catalog.citext(int4) RETURNS citext AS 'int4_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(int4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(int4) IS 'convert int4 to citext';
CREATE FUNCTION pg_catalog.int4(citext) RETURNS int4 AS 'text_int4'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.int4(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.int4(citext) IS 'convert citext to int4';
CREATE CAST (citext AS int4) WITH FUNCTION int4(citext);
CREATE CAST (int4 AS citext) WITH FUNCTION citext(int4);

CREATE FUNCTION pg_catalog.citext(name) RETURNS citext AS 'name_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(name) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(name) IS 'convert name to citext';
CREATE FUNCTION pg_catalog.name(citext) RETURNS name AS 'text_name'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.name(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.name(citext) IS 'convert citext to name';
CREATE CAST (citext AS name) WITH FUNCTION name(citext);
CREATE CAST (name AS citext) WITH FUNCTION citext(name);

CREATE FUNCTION pg_catalog.citext(float8) RETURNS citext AS 'float8_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(float8) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(float8) IS 'convert float8 to citext';
CREATE FUNCTION pg_catalog.float8(citext) RETURNS float8 AS 'text_float8'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.float8(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.float8(citext) IS 'convert citext to float8';
CREATE CAST (citext AS float8) WITH FUNCTION float8(citext);
CREATE CAST (float8 AS citext) WITH FUNCTION citext(float8);

CREATE FUNCTION pg_catalog.citext(float4) RETURNS citext AS 'float4_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(float4) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(float4) IS 'convert float4 to citext';
CREATE FUNCTION pg_catalog.float4(citext) RETURNS float4 AS 'text_float4'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.float4(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.float4(citext) IS 'convert citext to float4';
CREATE CAST (citext AS float4) WITH FUNCTION float4(citext);
CREATE CAST (float4 AS citext) WITH FUNCTION citext(float4);

CREATE FUNCTION pg_catalog.citext("char") RETURNS citext AS 'char_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext("char") TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext("char") IS 'convert char to citext';
CREATE FUNCTION pg_catalog."char"(citext) RETURNS "char" AS 'text_char'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog."char"(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog."char"(citext) IS 'convert citext to char';
CREATE CAST (citext AS "char") WITH FUNCTION "char"(citext);
CREATE CAST ("char" AS citext) WITH FUNCTION citext("char");

CREATE FUNCTION pg_catalog.citext(timetz) RETURNS citext AS 'timetz_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(timetz) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(timetz) IS 'convert timetz to citext';
CREATE FUNCTION pg_catalog.timetz(citext) RETURNS timetz AS 'text_timetz'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.timetz(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.timetz(citext) IS 'convert citext to timetz';
CREATE CAST (citext AS timetz) WITH FUNCTION timetz(citext);
CREATE CAST (timetz AS citext) WITH FUNCTION citext(timetz);

CREATE FUNCTION pg_catalog.citext("time") RETURNS citext AS 'time_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext("time") TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext("time") IS 'convert time to citext';
CREATE FUNCTION pg_catalog."time"(citext) RETURNS "time" AS 'text_time'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog."time"(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog."time"(citext) IS 'convert citext to time';
CREATE CAST (citext AS "time") WITH FUNCTION "time"(citext);
CREATE CAST ("time" AS citext) WITH FUNCTION citext("time");

CREATE FUNCTION pg_catalog.citext("date") RETURNS citext AS 'date_text'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext("date") TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext("date") IS 'convert date to citext';
CREATE FUNCTION pg_catalog."date"(citext) RETURNS "date" AS 'text_date'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog."date"(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog."date"(citext) IS 'convert citext to date';
CREATE CAST (citext AS date) WITH FUNCTION "date"(citext);
CREATE CAST ("date" AS citext) WITH FUNCTION citext("date");

CREATE FUNCTION pg_catalog.citext(timestamptz) RETURNS citext AS 'timestamptz_text'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(timestamptz) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(timestamptz) IS 'convert timestamp to citext';
CREATE FUNCTION pg_catalog.timestamptz(citext) RETURNS timestamptz AS 'text_timestamptz'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.timestamptz(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.timestamptz(citext) IS 'convert citext to timestamp with time zone';
CREATE CAST (citext AS timestamptz) WITH FUNCTION timestamptz(citext);
CREATE CAST (timestamptz AS citext) WITH FUNCTION citext(timestamptz);

CREATE FUNCTION pg_catalog.citext("interval") RETURNS citext AS 'interval_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext("interval") TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext("interval") IS 'convert interval to citext';
CREATE FUNCTION pg_catalog."interval"(citext) RETURNS "interval" AS 'text_interval'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog."interval"(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog."interval"(citext) IS 'convert citext to interval';
CREATE CAST (citext AS "interval") WITH FUNCTION "interval"(citext);
CREATE CAST ("interval" AS citext) WITH FUNCTION citext("interval");

CREATE FUNCTION pg_catalog.citext(int8) RETURNS citext AS 'int8_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(int8) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(int8) IS 'convert int8 to citext';
CREATE FUNCTION pg_catalog.int8(citext) RETURNS int8 AS 'text_int8'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.int8(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.int8(citext) IS 'convert citext to int8';
CREATE CAST (citext AS int8) WITH FUNCTION int8(citext);
CREATE CAST (int8 AS citext) WITH FUNCTION citext(int8);

CREATE FUNCTION pg_catalog.citext(macaddr) RETURNS citext AS 'macaddr_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(macaddr) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(macaddr) IS 'MAC address to citext';
CREATE FUNCTION pg_catalog.macaddr(citext) RETURNS macaddr AS 'text_macaddr'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.macaddr(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.macaddr(citext) IS 'citext to MAC address';
CREATE CAST (citext AS macaddr) WITH FUNCTION macaddr(citext);
CREATE CAST (macaddr AS citext) WITH FUNCTION citext(macaddr);

CREATE FUNCTION pg_catalog.citext("numeric") RETURNS citext AS 'numeric_text'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext("numeric") TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext("numeric") IS 'Numeric to citext';
CREATE FUNCTION pg_catalog."numeric"(citext) RETURNS "numeric" AS 'text_numeric'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog."numeric"(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog."numeric"(citext) IS 'citext to numeric';
CREATE CAST (citext AS "numeric") WITH FUNCTION "numeric"(citext);
CREATE CAST ("numeric" AS citext) WITH FUNCTION citext("numeric");

CREATE FUNCTION pg_catalog.citext("timestamp") RETURNS citext AS 'timestamp_text'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext("timestamp") TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext("timestamp") IS 'convert timestamp to citext';
CREATE FUNCTION pg_catalog."timestamp"(citext) RETURNS "timestamp" AS 'text_timestamp'  LANGUAGE 'internal' STABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog."timestamp"(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog."timestamp"(citext) IS 'convert citext to timestamp';
CREATE CAST (citext AS "timestamp") WITH FUNCTION "timestamp"(citext);
CREATE CAST ("timestamp" AS citext) WITH FUNCTION citext("timestamp");

CREATE FUNCTION pg_catalog.citext(inet) RETURNS citext AS 'network_show'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.citext(inet) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.citext(inet) IS 'show all parts of inet/cidr value';

CREATE FUNCTION pg_catalog.cidr(citext) RETURNS cidr AS 'text_cidr'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.cidr(citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.cidr(citext) IS 'citext to cidr';

CREATE FUNCTION pg_catalog.nameicregexne(name, citext) RETURNS bool AS 'nameicregexne'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.nameicregexne(name, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.nameicregexne(name, citext) IS 'does not match regex., case-insensitive';
CREATE FUNCTION pg_catalog.nameicregexeq(name, citext) RETURNS bool AS 'nameicregexeq'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.nameicregexeq(name, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.nameicregexeq(name, citext) IS 'matches regex., case-insensitive';
CREATE FUNCTION pg_catalog.nameicnlike(name, citext) RETURNS bool AS 'nameicnlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.nameicnlike(name, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.nameicnlike(name, citext) IS 'does not match LIKE expression, case-insensitive';
CREATE FUNCTION pg_catalog.nameiclike(name, citext) RETURNS bool AS 'nameiclike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.nameiclike(name, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.nameiclike(name, citext) IS 'matches LIKE expression, case-insensitive';

CREATE OPERATOR pg_catalog.~ (PROCEDURE = nameicregexeq, LEFTARG = name, RIGHTARG = citext, NEGATOR = !~, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.~* (PROCEDURE = nameicregexeq, LEFTARG = name, RIGHTARG = citext, NEGATOR = !~*, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.!~ (PROCEDURE = nameicregexne, LEFTARG = name, RIGHTARG = citext, NEGATOR = ~, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.!~* (PROCEDURE = nameicregexne, LEFTARG = name, RIGHTARG = citext, NEGATOR = ~*, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.~~ (PROCEDURE = nameiclike, LEFTARG = name, RIGHTARG = citext, NEGATOR = !~~, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.~~* (PROCEDURE = nameiclike, LEFTARG = name, RIGHTARG = citext, NEGATOR = !~~*, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.!~~ (PROCEDURE = nameicnlike, LEFTARG = name, RIGHTARG = citext, NEGATOR = ~~, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);
CREATE OPERATOR pg_catalog.!~~* (PROCEDURE = nameicnlike, LEFTARG = name, RIGHTARG = citext, NEGATOR = ~~, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);

CREATE FUNCTION pg_catalog.texticlike(varchar, citext) RETURNS bool AS 'texticlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticlike(varchar, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticlike(varchar, citext) IS 'matches LIKE expression, case-insensitive';
CREATE FUNCTION pg_catalog.texticnlike(varchar, citext) RETURNS bool AS 'texticnlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticnlike(varchar, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticnlike(varchar, citext) IS 'does not match LIKE expression, case-insensitive';
CREATE FUNCTION pg_catalog.texticregexeq(varchar, citext) RETURNS bool AS 'texticregexeq'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticregexeq(varchar, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticregexeq(varchar, citext) IS 'matches regex., case-insensitive';
CREATE FUNCTION pg_catalog.texticregexne(varchar, citext) RETURNS bool AS 'texticregexne'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticregexne(varchar, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticregexne(varchar, citext) IS 'does not match regex., case-insensitive';

CREATE OPERATOR pg_catalog.~ (PROCEDURE = texticregexeq, LEFTARG = varchar, RIGHTARG = citext, NEGATOR = !~, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.~* (PROCEDURE = texticregexeq, LEFTARG = varchar, RIGHTARG = citext, NEGATOR = !~*, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.!~ (PROCEDURE = texticregexne, LEFTARG = varchar, RIGHTARG = citext, NEGATOR = ~, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.!~* (PROCEDURE = texticregexne, LEFTARG = varchar, RIGHTARG = citext, NEGATOR = ~*, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.~~ (PROCEDURE = texticlike, LEFTARG = varchar, RIGHTARG = citext, NEGATOR = !~~, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.~~* (PROCEDURE = texticlike, LEFTARG = varchar, RIGHTARG = citext, NEGATOR = !~~*, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.!~~ (PROCEDURE = texticnlike, LEFTARG = varchar, RIGHTARG = citext, NEGATOR = ~~, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);
CREATE OPERATOR pg_catalog.!~~* (PROCEDURE = texticnlike, LEFTARG = varchar, RIGHTARG = citext, NEGATOR = ~~*, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);

CREATE FUNCTION pg_catalog.texticlike(bpchar, citext) RETURNS bool AS 'texticlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticlike(bpchar, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticlike(bpchar, citext) IS 'matches LIKE expression, case-insensitive';
CREATE FUNCTION pg_catalog.texticnlike(bpchar, citext) RETURNS bool AS 'texticnlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticnlike(bpchar, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticnlike(bpchar, citext) IS 'does not match LIKE expression, case-insensitive';
CREATE FUNCTION pg_catalog.texticregexeq(bpchar, citext) RETURNS bool AS 'texticregexeq'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticregexeq(bpchar, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticregexeq(bpchar, citext) IS 'matches regex., case-insensitive';
CREATE FUNCTION pg_catalog.texticregexne(bpchar, citext) RETURNS bool AS 'texticregexne'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticregexne(bpchar, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticregexne(bpchar, citext) IS 'does not match regex., case-insensitive';

CREATE OPERATOR pg_catalog.~ (PROCEDURE = texticregexeq, LEFTARG = bpchar, RIGHTARG = citext, NEGATOR = !~, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.~* (PROCEDURE = texticregexeq, LEFTARG = bpchar, RIGHTARG = citext, NEGATOR = !~*, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.!~ (PROCEDURE = texticregexne, LEFTARG = bpchar, RIGHTARG = citext, NEGATOR = ~, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.!~* (PROCEDURE = texticregexne, LEFTARG = bpchar, RIGHTARG = citext, NEGATOR = ~*, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.~~ (PROCEDURE = texticlike, LEFTARG = bpchar, RIGHTARG = citext, NEGATOR = !~~, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.~~* (PROCEDURE = texticlike, LEFTARG = bpchar, RIGHTARG = citext, NEGATOR = !~~*, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.!~~ (PROCEDURE = texticnlike, LEFTARG = bpchar, RIGHTARG = citext, NEGATOR = ~~, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);
CREATE OPERATOR pg_catalog.!~~* (PROCEDURE = texticnlike, LEFTARG = bpchar, RIGHTARG = citext, NEGATOR = ~~*, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);

CREATE FUNCTION pg_catalog.texticlike(text, citext) RETURNS bool AS 'texticlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticlike(text, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticlike(text, citext) IS 'matches LIKE expression, case-insensitive';
CREATE FUNCTION pg_catalog.texticnlike(text, citext) RETURNS bool AS 'texticnlike'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticnlike(text, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticnlike(text, citext) IS 'does not match LIKE expression, case-insensitive';
CREATE FUNCTION pg_catalog.texticregexeq(text, citext) RETURNS bool AS 'texticregexeq'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticregexeq(text, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticregexeq(text, citext) IS 'matches regex., case-insensitive';
CREATE FUNCTION pg_catalog.texticregexne(text, citext) RETURNS bool AS 'texticregexne'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.texticregexne(text, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.texticregexne(text, citext) IS 'does not match regex., case-insensitive';

CREATE OPERATOR pg_catalog.~ (PROCEDURE = texticregexeq, LEFTARG = text, RIGHTARG = citext, NEGATOR = !~, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.~* (PROCEDURE = texticregexeq, LEFTARG = text, RIGHTARG = citext, NEGATOR = !~*, RESTRICT = icregexeqsel, JOIN = icregexeqjoinsel);
CREATE OPERATOR pg_catalog.!~ (PROCEDURE = texticregexne, LEFTARG = text, RIGHTARG = citext, NEGATOR = ~, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.!~* (PROCEDURE = texticregexne, LEFTARG = text, RIGHTARG = citext, NEGATOR = ~*, RESTRICT = icregexnesel, JOIN = icregexnejoinsel);
CREATE OPERATOR pg_catalog.~~ (PROCEDURE = texticlike, LEFTARG = text, RIGHTARG = citext, NEGATOR = !~~, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.~~* (PROCEDURE = texticlike, LEFTARG = text, RIGHTARG = citext, NEGATOR = !~~*, RESTRICT = iclikesel, JOIN = iclikejoinsel);
CREATE OPERATOR pg_catalog.!~~ (PROCEDURE = texticnlike, LEFTARG = text, RIGHTARG = citext, NEGATOR = ~~, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);
CREATE OPERATOR pg_catalog.!~~* (PROCEDURE = texticnlike, LEFTARG = text, RIGHTARG = citext, NEGATOR = ~~*, RESTRICT = icnlikesel, JOIN = icnlikejoinsel);

CREATE FUNCTION pg_catalog.like_escape(citext, citext) RETURNS citext AS 'like_escape'  LANGUAGE 'internal' IMMUTABLE STRICT;
GRANT EXECUTE ON FUNCTION pg_catalog.like_escape(citext, citext) TO PUBLIC;
COMMENT ON FUNCTION pg_catalog.like_escape(citext, citext) IS 'convert LIKE pattern to use backslash escapes';


